<template>
  <div class="common-page-shadow">
    <div class="common-search-container" ref="contentPanel">
      <el-form
        ref="form"
        :model="searchForm"
        label-width="auto"
        type="flex"
        justify="left"
      >
        <el-row :gutter="25">
          <el-col :span="7">
            <el-form-item label="收费站">
              <el-select
                clearable
                size="small"
                v-model="searchForm.tollStationId"
                filterable
                placeholder="收费站"
              >
                <el-option
                  v-for="(item, index) in tollStationData"
                  :key="index"
                  :label="item.name"
                  :value="item.id"
                >
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="7">
            <el-form-item label="设备名称">
              <el-input
                size="small"
                v-model="searchForm.deviceName"
                clearable
                placeholder="请输入设备名称"
              ></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="2">
            <el-button
              size="small"
              icon="el-icon-search"
              type="primary"
              class="btn btn-plus"
              @click="handleSearch"
            >
              {{ this.$t('common.search') }}
            </el-button>
          </el-col>
          <el-col :span="2">
            <el-button
              size="small"
              icon="el-icon-refresh-right"
              class="btn btn-plus"
              @click="clearSearchForm"
            >
              重置
            </el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <el-row
      class="common-table-container flex searchPanel"
      :style="SearchPanel"
    >
      <el-col :span="24" class="common-table-wrapper">
        <div class="common-btn-group">
          <el-button
            size="small"
            icon="el-icon-plus"
            type="primary"
            class="btn btn-plus"
            v-methodauth="'saveRoute'"
            @click="handleAdd"
          >
            {{ this.$t('common.add') }}
          </el-button>
          <el-button
            size="small"
            slot="reference"
            icon="el-icon-delete"
            type="danger"
            class="btn btn-delete"
            @click="handleDelete"
            v-methodauth="'delRoute'"
            :disabled="deleteIds.length ? false : true"
          >
            {{ this.$t('common.delete') }}
          </el-button>
        </div>
        <!-- LJ：表格高度自适应需配合样式  btn-pagenation 有按钮有分页  btngroup只有按钮  pagenation只有分页 -->
        <div class="common-table-content btn-pagenation">
          <el-table
            :border="true"
            stripe
            fit
            size="mini"
            v-loading="tableLoading"
            ref="multipleSelection"
            :data="tableData"
            height="100%"
            @selection-change="handleSelectionChange"
          >
            <el-table-column type="selection" width="55" align="center">
            </el-table-column>
            <el-table-column
              prop="deviceCode"
              show-overflow-tooltip
              align="left"
              label="设备编号"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="deviceName"
              show-overflow-tooltip
              align="left"
              label="设备名称"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="tollStationName"
              show-overflow-tooltip
              align="left"
              label="所属收费站"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="positionPathName"
              show-overflow-tooltip
              align="left"
              label="所属位置"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="showContext"
              show-overflow-tooltip
              align="left"
              label="当前展示内容"
              resizable
            >
            </el-table-column>

            <el-table-column width="60" align="left" label="操作">
              <template v-slot="{row}">
                <template>
                  <el-button
                    type="text"
                    size="small"
                    v-methodauth="'saveRoute'"
                    @click="handleEdit(row)"
                    >编辑</el-button
                  >
                </template>
              </template>
            </el-table-column>
          </el-table>
        </div>
        <div class="common-pagenation">
          <el-pagination
            ref="paginationPanel"
            background
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
            :current-page="params.pageBean.page"
            :page-sizes="[20, 30, 40, 50]"
            :page-size="params.pageBean.pageSize"
            layout="total, sizes, prev, pager, next, jumper"
            :total="params.pageBean.total"
          >
          </el-pagination>
        </div>
      </el-col>
    </el-row>
    <!-- 弹层 -->
    <el-dialog
      :title="dialog.title"
      :visible.sync="dialog.visible"
      width="35%"
      top="18vh"
      :before-close="handleDialogClose"
      :close-on-click-modal="false"
      :destroy-on-close="true"
    >
      <el-form
        ref="form"
        :model="dialogForm"
        :rules="rules"
        label-width="100px"
        label-position="right"
        v-loading="loading"
        :disabled="disabledDetils"
        border
      >
        <el-row :gutter="20" type="flex" class="flex-wrap">
          <el-col :span="22">
            <el-form-item label="设备名称" prop="deviceName">
              <el-select
                clearable
                size="small"
                v-model="dialogForm.deviceName"
                filterable
                placeholder="设备名称"
              >
                <el-option
                  v-for="(item, index) in deviceData"
                  :key="index"
                  :label="item.name"
                  :value="item.name"
                >
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="22">
            <el-form-item label="当前展示内容">
              <el-input
                type="textarea"
                v-model="dialogForm.showContext"
                placeholder="当前展示内容..."
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button @click="dialog.visible = false" size="small">
          取消
        </el-button>
        <template v-if="!disabledDetils">
          <el-button type="primary" @click="submit()" size="small">
            提交
          </el-button>
        </template>
      </span>
    </el-dialog>
  </div>
</template>
      
      <script>
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import tollStationManagement from '@/api/BasicDataManagement/tollStationManagement.js'
import device from '@/api/DeviceManagement/device.js'
export default {
  name: 'controDevice',
  mixins: [TableMixin, pagination],
  data() {
    return {
      disabledDetils: false,
      currentPage: 1,
      tableMaxHeight: 400,
      loading: false,
      tableLoading: false,
      tableData: [],
      multipleSelection: [],
      params: {
        pageBean: {
          page: 1,
          pageSize: 20,
          total: 0,
        },
      },
      searchForm: {}, // 顶部搜索对象
      tollStationData: [],
      tollStationId: '',
      value: '',
      allData: {
        pageBean: {
          page: 1,
          pageSize: -1,
          total: 0,
        },
      },
      deviceData: [],
      dialog: {
        title: '添加',
        visible: false,
      },
      deleteIds: '', // 是否选中列表解锁删除按钮
      dialog: {
        title: '添加',
        visible: false,
      },
      dialogForm: {},
      disabled: false, // 是否禁止输入输入
      edit: false, // 是否是修改功能
      rules: {
        deviceName: {
          required: true,
          message: '请输入路线编号',
          trigger: 'blur',
        },
        showContext: {
          required: true,
          message: '请选择路线名称',
          trigger: 'blur',
        },
      },
    }
  },
  created() {
    this.tollStationId = sessionStorage.getItem('tollStationId')
    this.searchForm.tollStationId = this.tollStationId
    this.loadTollStation()
    this.getDeviceControl(1)
    this.loadDeviceData()
  },
  methods: {
    // 获取设备控制数据
    getDeviceControl(page) {
      if (page) this.params.pageBean.page = page
      this.tableLoading = true
      device.queryDeviceControl(this.params).then((res) => {
        this.tableLoading = false
        let data = res.data.value
        this.tableData = data.rows || []
        if (data.page) {
          this.params.pageBean = {
            page: data.page,
            pageSize: data.pageSize,
            total: data.total,
          }
        }
        this.params.querys = []
      })
    },
    //获取设备数据
    loadDeviceData() {
      this.deviceData = []
      device.queryDeviceList(this.allData).then((res) => {
        for (let i = 0; i < res.value.rows.length; i++) {
          let obj = []
          if (res.value.rows[i].isController == 1) {
            obj = {
              code: res.value.rows[i].code,
              name: res.value.rows[i].name,
              tollStationName: res.value.rows[i].tollStationName,
              tollStationId: res.value.rows[i].tollStationId,
              isController: res.value.rows[i].isController,
              positionPathName: res.value.rows[i].positionPathName,
            }
            this.deviceData.push(obj)
          }
        }
      })
    },
    // 获取收费站数据
    loadTollStation() {
      tollStationManagement.queryTollStation(this.allData).then((res) => {
        let obj = []
        for (let i = 0; i < res.data.rows.length; i++) {
          obj = {
            id: res.data.rows[i].id,
            name: res.data.rows[i].name,
            roadName: res.data.rows[i].roadSegmentName,
            roadId: res.data.rows[i].roadSegmentId,
          }
          this.tollStationData.push(obj)
        }
      })
    },
    // 弹层关闭
    handleDialogClose() {
      this.dialog.visible = false
    },
    //添加
    handleAdd() {
      this.edit = false
      this.disabledDetils = false
      this.dialogForm = {}
      this.dialog.title = '添加'
      this.dialog.visible = true
    },
    // 编辑
    handleEdit(rows) {
      this.$refs.form.clearValidate()
      this.edit = true
      this.disabledDetils = false
      this.dialogForm = rows || {}
      this.dialogForm = {
        ...rows,
      }
      this.dialog.title = '编辑'
      this.dialog.visible = true
    },
    // 顶部搜索
    handleSearch() {
      let obj = this.searchForm
      let querys = []
      for (let i in obj) {
        if (obj[i]) {
          querys.push({
            group: 'main',
            operation:
              i == 'tollStationId' || i == 'deviceName' ? 'LIKE' : 'EQUAL',
            parentGroup: '',
            property: i,
            relation: 'AND',
            value: obj[i],
          })
        }
      }
      this.params.querys = querys
      this.getDeviceControl(1)
    },
    // 表单提交保存
    submit() {
      for (let i = 0; i < this.deviceData.length; i++) {
        if (this.dialogForm.deviceName == this.deviceData[i].name) {
          this.dialogForm.deviceCode = this.deviceData[i].code
          this.dialogForm.tollStationName = this.deviceData[i].tollStationName
          this.dialogForm.isController = this.deviceData[i].isController
          this.dialogForm.positionPathName = this.deviceData[i].positionPathName
          this.dialogForm.tollStationId = this.deviceData[i].tollStationId
        }
      }
      this.$refs.form.validate((valid) => {
        if (valid) {
          this.loading = true
          device
            .addDeviceControl(this.dialogForm)
            .then((res) => {
              if (res.data.state) {
                this.dialog.visible = false
                this.getDeviceControl(1)
              }
              if (!res.errorMsg) {
                this.$message({
                  message: !this.edit ? '添加成功' : '修改成功',
                  type: 'success',
                })
                this.editVisible = false
              }
              this.loading = false
            })
            .catch(() => {
              this.loading = false
            })
        } else {
          return false
        }
      })
    },
    // 删除
    handleDelete() {
      this.$confirm(this.$t('common.sureDelete'), this.$t('common.tips'), {
        confirmButtonText: this.$t('common.confirm'),
        cancelButtonText: this.$t('common.cancel'),
        type: 'warning',
      }).then(() => {
        device.batchControlDelete(this.deleteIds).then((res) => {
          this.getDeviceControl(1)
          if (!res.errorMsg) {
            this.$message({
              message: '删除成功',
              type: 'success',
            })
          }
        })
      })
    },
  },

  mounted() {
    this.calcTableHeight()
    this.$root.$on('resize', () => {
      this.calcTableHeight(500)
    })
  },
  computed: {
    SearchPanel() {
      return {
        '--searchPanel': this.searchPanel + 'px',
      }
    },
  },
}
</script>
      
      <style lang="scss" scoped>
      
      
      
      </style>